@@ -1588,11 +1588,11 @@ def sampling(models, X, y, args):
   intr_mode_area = args['intr_mode_area']
   if metrc == "auto":
     if intr_mode_area == "classification":
-      metrc = "accuracy"
+      args['intr_eval_mtrc'] = "accuracy"
     elif intr_mode_area == "regression":
-      metrc = "r2"
+      args['intr_eval_mtrc'] = "r2"
   else:
-    metrc = metrc
+    args['intr_eval_mtrc'] = metrc
 
   print("====================== Model Performance ======================")
   for model in models:
@@ -1606,13 +1606,15 @@ def sampling(models, X, y, args):
     time_str = tm.time()
     #############################################################################################################################################################
     model_init = None
+    model_objt = None
+    metrc = args['intr_eval_mtrc']
     mode_eval_meth = args["mode_eval_meth"]
+
     ###MODEL OVD###
     model = space_override(model, args, mode_eval_meth)
     if mode_eval_meth == "none":
       ###MODEL INI###
-      model_init = model["model"]
-      model_init = model["model"]
+      model_objt = model["model"]
       ###MODEL FIT###
       if dtype == "frame":
         model_init.fit(X, y.values.ravel())
@@ -1641,8 +1643,8 @@ def sampling(models, X, y, args):
         model_init.fit(X, y.values.ravel())
       else:
         model_init.fit(X, y)
-      model_rlts = pd.DataFrame(model_init.cv_results_)
       model_indx = model_init.best_index_
+      model_rlts = pd.DataFrame(model_init.cv_results_)
       ###MODEL SCR###
       model_scra = round(model_rlts['mean_train_score'][model_indx], 2) #Returns score on known data / seen data
       model_scrb = round(model_rlts['mean_test_score'][model_indx], 2) #Returns score on unknown data / unseen data
@@ -1656,6 +1658,7 @@ def sampling(models, X, y, args):
       dict_info = {
         "model_idnm": model_idnm,
         "model_name": model_name,
+        "model_init": model_init,
         "model_objt": model_objt,
         "model_mtrc": metrc,
         "model_scra": model_scra,
@@ -1692,11 +1695,12 @@ def find(models, data_specs, X, y, args):
   print(df_models_infos[dict_columns].to_string())
   return df_models_infos
 
-def best(df_models):
+def best(df_models, sample):
   df_models = df_models[df_models["model_scrb"] == df_models["model_scrb"].max()]
   df_models = df_models[df_models["model_dura"] == df_models["model_dura"].min()]
   best_model = df_models.reset_index(level=0).iloc[0]
   best_model_name = best_model["model_name"]
+  best_model_init = best_model["model_init"]
   best_model_objt = best_model["model_objt"]
   best_model_mtrc = best_model["model_mtrc"]
   best_model_scra = best_model["model_scra"]
@@ -1709,14 +1713,37 @@ def best(df_models):
   print("Model Testing Score: {0}".format(detect_format(best_model_mtrc, best_model_scrb)))
   print("Model Process Duration: {0}".format(detect_format("time", best_model_dura)))
   print("Model Process Parameters: {0}".format(best_model_spac))
-  return best_model_objt
+
+  best_model = None
+  if sample == True:
+    best_model = best_model_objt
+  else:
+    best_model = best_model_init
+  return best_model
 
 def trai(model, X, y, args):
+  time_str = tm.time()
   dtype = args["intr_data_type"]
   if dtype == "frame":
     model.fit(X, y.values.ravel())
   else:
     model.fit(X, y)
+  time_end = tm.time()
+
+  model_name = type(model.estimator).__name__
+  model_indx = model.best_index_
+  model_rlts = pd.DataFrame(model.cv_results_)
+  model_scra = round(model_rlts['mean_train_score'][model_indx], 2) #Returns score on known data / seen data
+  model_scrb = round(model_rlts['mean_test_score'][model_indx], 2) #Returns score on unknown data / unseen data 
+  model_dura = round(time_end - time_str, 2)
+  model_mtrc = args['intr_eval_mtrc']
+  model_spac = model.best_params_
+  print("====================== Complete Training ======================")
+  print("Model Name: {0}".format(model_name))
+  print("Model Training Score: {0}".format(detect_format(model_mtrc, model_scra)))
+  print("Model Testing Score: {0}".format(detect_format(model_mtrc, model_scrb)))
+  print("Model Process Duration: {0}".format(detect_format("time", model_dura)))
+  print("Model Process Parameters: {0}".format(model_spac))
   return model
 
 def pred(model, X, y, args):
@@ -1749,7 +1776,7 @@ def auto_ml_train(df: None, args):
   models = load_models(args)
   models = model_manage(df_tmp, models, args)
   models = find(models, data_specs, X, y, args)
-  model = best(models)
+  modelx = best(models, sample["smpl_mode"])
 
   #Complete Method
   if sample["smpl_mode"] == True:
@@ -1763,14 +1790,19 @@ def auto_ml_train(df: None, args):
     drop_rows = args['mode_pres_drop_rows']
 
     df_tmp = df
+    print("hereee")
     df_tmp = load_data(df_tmp, args)
     df_tmp = drop_xxxs(df_tmp, drop_cols, 1, args)
     df_tmp = drop_xxxs(df_tmp, drop_rows, 0, args)
     df_nums, df_strs, df_cats, df_clas, data_feats = data_manage(df_tmp, args, data_feats)
     X, y, data_specs, data_encos = preprocessing(df_nums, df_strs, df_cats, df_clas, args, data_encos)
 
-  #Train Method
-  model = trai(model, X, y, args)
+    #With Refit Method
+    model = trai(modelx, X, y, args)
+  else:
+    #Without Refit Method
+    model = modelx
+
   model_args = {'model': model, 'feats': data_feats, 'encos': data_encos }
   return model_args
 
@@ -1797,4 +1829,4 @@ def auto_ml_pred(df: None, args, model_args):
     #Pred Method
     model = model_args["model"]
     y_hat, y_act = pred(model, X, y, args)
-    return y_hat, y_act
+    return y_hat, y_act
\ No newline at end of file
